/**
 * ProjectLaogai
 *
 * Copyright 2019  <seil0@mosad.xyz>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 */

package org.mosad.seil0.projectlaogai.hsoparser

import org.jsoup.Jsoup
import java.util.*
import kotlin.collections.ArrayList

class MensaParser {

    /**
     * returns the mensa menu for the a week
     */
    fun getMensaMenu(menuLink: String): MealWeek {
        val mealList = ArrayList<Meal>()
        val mealWeekList = MealWeek()
        val menuHTML = Jsoup.connect(menuLink).get()

        menuHTML.select("#speiseplan-tabs").select("div.tab-content").select("div.menu-tagesplan").forEachIndexed { dayIndex, day ->
            val strDay = day.select("h3").text()


            day.select("div.menu-info").forEachIndexed { mealIndex, meal ->
                val heading = day.select("h4")[mealIndex].text()
                val parts = ArrayList(meal.html().substringBefore("<br>\n").replace("<br>", " ").split("\n"))
                val additives = meal.select("span.show-with-allergenes").text()

                mealWeekList.day[dayIndex].add(Meal(strDay, heading, parts, additives))
            }

            for (i in 0 .. (day.select("div.row  h4").size - 1)) {
                try {
                    val heading = day.select("div.row  h4")[i].text()
                    val parts = ArrayList<String>(day.select("div.row").select("div.menu-info")[i].html().substringBefore("<span").replace("<br>", " ").split("\n"))
                    val additives = day.select("div.row").select("div.menu-info")[i].select("span.show-with-allergenes").text()

                    mealList.add(Meal(strDay, heading, parts, additives))
                } catch (e: Exception) {
                    //println("Oooups! Something went wrong: ${e.printStackTrace()}")
                }
            }
        }

        // Mon to Sat (0 - 5)
        //println(mealWeekList.day[4])

        return  mealWeekList
    }

    /**
     * return the link of the menus of the next week
     */
    fun getMenuLinkNextWeek(menuLink: String): String {
        val menuHTML = Jsoup.connect(menuLink).get()

        return "https://www.swfr.de" + menuHTML.select("#speiseplan-tabs").select("a.next-week").attr("href")
    }
}
